==> jc-1.4.0.tar.gz: gnu/java/lang/ArrayHelper.h <==
// public class gnu.java.lang.ArrayHelper

// class file dependencies
// @dep_class b29606ef395bd20d gnu_java_lang_ArrayHelper
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_lang_ArrayHelper_H_
#define _JC_gnu_java_lang_ArrayHelper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_lang_ArrayHelper$sub_refs	_jc_gnu_java_lang_ArrayHelper$sub_refs;
typedef struct _jc_gnu_java_lang_ArrayHelper$sub_nonrefs	_jc_gnu_java_lang_ArrayHelper$sub_nonrefs;
typedef struct _jc_gnu_java_lang_ArrayHelper$refs	_jc_gnu_java_lang_ArrayHelper$refs;
typedef struct _jc_gnu_java_lang_ArrayHelper$nonrefs	_jc_gnu_java_lang_ArrayHelper$nonrefs;
typedef struct _jc_gnu_java_lang_ArrayHelper$object	_jc_gnu_java_lang_ArrayHelper$object;

typedef const struct _jc_gnu_java_lang_ArrayHelper$vmethods	_jc_gnu_java_lang_ArrayHelper$vmethods;
typedef const struct _jc_gnu_java_lang_ArrayHelper$vtable	_jc_gnu_java_lang_ArrayHelper$vtable;
typedef const struct _jc_gnu_java_lang_ArrayHelper$vtype	_jc_gnu_java_lang_ArrayHelper$vtype;

// Constructors
extern void _jc_gnu_java_lang_ArrayHelper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_lang_ArrayHelper$object *);

// Static methods
extern jboolean _jc_gnu_java_lang_ArrayHelper$method$contains$40c3b9ab27aa174a(_jc_env *, struct _jc_object_array *, struct _jc_java_lang_Object$object *);
extern jint _jc_gnu_java_lang_ArrayHelper$method$indexOf$95017df0e9e73220(_jc_env *, struct _jc_object_array *, struct _jc_java_lang_Object$object *);

// Virtual methods structure
struct _jc_gnu_java_lang_ArrayHelper$vmethods {
};

// Vtable
struct _jc_gnu_java_lang_ArrayHelper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_lang_ArrayHelper$vmethods	gnu_java_lang_ArrayHelper;
};

// Vtype
struct _jc_gnu_java_lang_ArrayHelper$vtype {
	_jc_type			type;
	_jc_gnu_java_lang_ArrayHelper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_lang_ArrayHelper$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_lang_ArrayHelper$refs {
    _jc_gnu_java_lang_ArrayHelper$sub_refs	gnu_java_lang_ArrayHelper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_lang_ArrayHelper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_lang_ArrayHelper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_lang_ArrayHelper$sub_nonrefs	gnu_java_lang_ArrayHelper;
};

// Object instance structure
struct _jc_gnu_java_lang_ArrayHelper$object {
	_jc_gnu_java_lang_ArrayHelper$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_lang_ArrayHelper$vtype	*vtype;
	_jc_gnu_java_lang_ArrayHelper$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_lang_ArrayHelper$vtype _jc_gnu_java_lang_ArrayHelper$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_lang_ArrayHelper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_lang_ArrayHelper$class_object;

#endif	/* _JC_gnu_java_lang_ArrayHelper_H_ */

==> jc-1.4.6.tar.gz: gnu/java/lang/ArrayHelper.h <==
// public class gnu.java.lang.ArrayHelper

// class file dependencies
// @dep_class b29606ef395bd20d gnu_java_lang_ArrayHelper
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_lang_ArrayHelper_H_
#define _JC_gnu_java_lang_ArrayHelper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_lang_ArrayHelper$sub_refs	_jc_gnu_java_lang_ArrayHelper$sub_refs;
typedef struct _jc_gnu_java_lang_ArrayHelper$sub_nonrefs	_jc_gnu_java_lang_ArrayHelper$sub_nonrefs;
typedef struct _jc_gnu_java_lang_ArrayHelper$refs	_jc_gnu_java_lang_ArrayHelper$refs;
typedef struct _jc_gnu_java_lang_ArrayHelper$nonrefs	_jc_gnu_java_lang_ArrayHelper$nonrefs;
typedef struct _jc_gnu_java_lang_ArrayHelper$object	_jc_gnu_java_lang_ArrayHelper$object;

typedef const struct _jc_gnu_java_lang_ArrayHelper$vmethods	_jc_gnu_java_lang_ArrayHelper$vmethods;
typedef const struct _jc_gnu_java_lang_ArrayHelper$vtable	_jc_gnu_java_lang_ArrayHelper$vtable;
typedef const struct _jc_gnu_java_lang_ArrayHelper$vtype	_jc_gnu_java_lang_ArrayHelper$vtype;

// Constructors
extern void _jc_gnu_java_lang_ArrayHelper$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_lang_ArrayHelper$object *) _JC_JCNI_ATTR;

// Static methods
extern jboolean _jc_gnu_java_lang_ArrayHelper$method$contains$40c3b9ab27aa174a(_jc_env *, struct _jc_object_array *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_lang_ArrayHelper$method$indexOf$95017df0e9e73220(_jc_env *, struct _jc_object_array *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_lang_ArrayHelper$vmethods {
};

// Vtable
struct _jc_gnu_java_lang_ArrayHelper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_lang_ArrayHelper$vmethods	gnu_java_lang_ArrayHelper;
};

// Vtype
struct _jc_gnu_java_lang_ArrayHelper$vtype {
	_jc_type			type;
	_jc_gnu_java_lang_ArrayHelper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_lang_ArrayHelper$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_lang_ArrayHelper$refs {
    _jc_gnu_java_lang_ArrayHelper$sub_refs	gnu_java_lang_ArrayHelper;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_lang_ArrayHelper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_lang_ArrayHelper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_lang_ArrayHelper$sub_nonrefs	gnu_java_lang_ArrayHelper;
};

// Object instance structure
struct _jc_gnu_java_lang_ArrayHelper$object {
	_jc_gnu_java_lang_ArrayHelper$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_lang_ArrayHelper$vtype	*vtype;
	_jc_gnu_java_lang_ArrayHelper$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_lang_ArrayHelper$vtype _jc_gnu_java_lang_ArrayHelper$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_lang_ArrayHelper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_lang_ArrayHelper$class_object;

#endif	/* _JC_gnu_java_lang_ArrayHelper_H_ */
